# PAYWIX

Paywix is a lightweight SDK for payment processing for the python based applications, the package 
was initially supported only with the Django framework. In the new version, the package is supported 
by all python-based applications.

### Currently supported Payment Gateways
  - Payu

### Installation
* Python > 3 Version

```python
1. pip install paywix
2. pipenv install paywix
```

### Plugins

Paywix is currently extended with the following plugins. Instructions on how to use them in your own application are detailed below.

| Plugin | README |
| ------ | ------ |
| PAYU | https://github.com/renjithsraj/paywix/blob/master/PAYU.md 

### Todos
 - Paytm
 - Cashfree
 - Stripe
 - Braintree
 - CCavenue

License
----

MIT

